#!perl

# Name: Array sorting
# Require: 4
# Desc:
#


require 'benchlib.pl';

@a = ();
while (<DATA>) {
    chop;
    push(@a, $_);
}
srand(10);
push(@b, splice(@a, rand(@a), 1)) while @a;  # shuffle

&runtest(0.3, <<'ENDTEST');

    @a = sort @b;

ENDTEST


# The first part of /usr/dict/words
__END__
Aarhus
Aaron
Ababa
aback
abaft
abandon
abandoned
abandoning
abandonment
abandons
abase
abased
abasement
abasements
abases
abash
abashed
abashes
abashing
abasing
abate
abated
abatement
abatements
abater
abates
abating
Abba
abbe
abbey
abbeys
abbot
abbots
Abbott
abbreviate
abbreviated
abbreviates
abbreviating
abbreviation
abbreviations
Abby
abdomen
abdomens
abdominal
abduct
abducted
abduction
abductions
abductor
abductors
abducts
Abe
abed
Abel
Abelian
Abelson
Aberdeen
Abernathy
aberrant
aberration
aberrations
abet
abets
abetted
abetter
abetting
abeyance
abhor
abhorred
abhorrent
abhorrer
abhorring
abhors
abide
abided
abides
abiding
Abidjan
Abigail
Abilene
abilities
ability
abject
abjection
abjections
abjectly
abjectness
abjure
abjured
abjures
abjuring
ablate
ablated
ablates
ablating
ablation
ablative
ablaze
able
abler
ablest
ably
Abner
abnormal
abnormalities
abnormality
abnormally
Abo
aboard
abode
abodes
abolish
abolished
abolisher
abolishers
abolishes
abolishing
abolishment
abolishments
abolition
abolitionist
abolitionists
abominable
abominate
aboriginal
aborigine
aborigines
abort
aborted
aborting
abortion
abortions
abortive
abortively
aborts
Abos
abound
abounded
abounding
abounds
about
above
aboveboard
aboveground
abovementioned
abrade
abraded
abrades
abrading
Abraham
Abram
Abrams
Abramson
abrasion
abrasions
abrasive
abreaction
abreactions
abreast
abridge
abridged
abridges
abridging
abridgment
abroad
abrogate
abrogated
abrogates
abrogating
abrupt
abruptly
abruptness
abscess
abscessed
abscesses
abscissa
abscissas
abscond
absconded
absconding
absconds
absence
absences
absent
absented
absentee
absenteeism
absentees
absentia
absenting
absently
absentminded
absents
absinthe
absolute
absolutely
absoluteness
absolutes
absolution
absolve
absolved
absolves
absolving
absorb
absorbed
absorbency
absorbent
absorber
absorbing
absorbs
absorption
absorptions
absorptive
abstain
abstained
abstainer
abstaining
abstains
abstention
abstentions
abstinence
abstract
abstracted
abstracting
abstraction
abstractionism
abstractionist
abstractions
abstractly
abstractness
abstractor
abstractors
abstracts
abstruse
abstruseness
absurd
absurdities
absurdity
absurdly
Abu
abundance
abundant
abundantly
abuse
abused
abuses
abusing
abusive
abut
abutment
abuts
abutted
abutter
abutters
abutting
abysmal
abysmally
abyss
abysses
Abyssinia
Abyssinian
Abyssinians
acacia
academia
academic
academically
academics
academies
academy
Acadia
Acapulco
accede
acceded
accedes
accelerate
accelerated
accelerates
accelerating
acceleration
accelerations
accelerator
accelerators
accelerometer
accelerometers
accent
accented
accenting
accents
accentual
accentuate
accentuated
accentuates
accentuating
accentuation
accept
acceptability
acceptable
